@@ -1,8 +1,8 @@
 /*
 **  OSSP xds - Extensible Data Serialization
-**  Copyright (c) 2001-2004 Ralf S. Engelschall <rse@engelschall.com>
-**  Copyright (c) 2001-2004 The OSSP Project <http://www.ossp.org/>
-**  Copyright (c) 2001-2004 Cable & Wireless <http://www.cw.com/>
+**  Copyright (c) 2001-2005 Ralf S. Engelschall <rse@engelschall.com>
+**  Copyright (c) 2001-2005 The OSSP Project <http://www.ossp.org/>
+**  Copyright (c) 2001-2005 Cable & Wireless <http://www.cw.com/>
 **
 **  This file is part of OSSP xds, an extensible data serialization
 **  library which can be found at http://www.ossp.org/pkg/lib/xds/.
@@ -696,7 +696,7 @@ int xdr_decode_string(xds_t *xds, void *engine_context,
 
     /* Copy data into the buffer. */
     memmove(*p, (xds_uint8_t *)buffer + 4, p_len);
-    ((xds_uint8_t *)buffer)[4 + p_len] = '\0';
+    (*p)[p_len] = '\0';
 
     return XDS_OK;
 }
